@@ -12,6 +12,7 @@
 #'   \code{browseVignettes("roxygen2")}
 #' @export
 document <- function(pkg = ".", clean = NULL, roclets = NULL, reload = TRUE) {
+  check_suggested("roxygen2")
   if (!missing(clean)) {
     warning("`clean` is deprecated: roxygen2 now automatically cleans up",
       call. = FALSE)
@@ -25,7 +26,13 @@ document <- function(pkg = ".", clean = NULL, roclets = NULL, reload = TRUE) {
 
   load_all(pkg)
 
-  with_envvar(r_env_vars(),
+  if (packageVersion("roxygen2") > "4.1.1") {
+    roclets <- roclets %||% roxygen2::load_options(pkg$path)$roclets
+    # collate updated by load_all()
+    roclets <- setdiff(roclets, "collate")
+  }
+
+  withr::with_envvar(r_env_vars(),
     roxygen2::roxygenise(pkg$path, roclets = roclets, load_code = ns_env)
   )
 
