@@ -12,87 +12,70 @@ NULL
 #' add \pkg{testthat} to the suggested packages. This is called
 #' automatically from \code{\link{test}} if needed.
 #' @rdname infrastructure
-#' @aliases add_test_infrastructure
 #' @export
 use_testthat <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
   check_suggested("testthat")
-  if (uses_testthat(pkg)) {
+  if (uses_testthat(pkg = pkg)) {
     message("* testthat is already initialized")
     return(invisible(TRUE))
   }
 
-  # Create tests/testthat and install file for R CMD CHECK
-  dir.create(file.path(pkg$path, "tests", "testthat"),
-    showWarnings = FALSE, recursive = TRUE)
-  writeLines(render_template("testthat.R", list(name = pkg$package)),
-    file.path(pkg$path, "tests", "testthat.R"))
-
+  message("* Adding testthat to Suggests")
   add_desc_package(pkg, "Suggests", "testthat")
 
+  use_directory("tests/testthat", pkg = pkg)
+  use_template(
+    "testthat.R",
+    "tests/testthat.R",
+    data = list(name = pkg$package),
+    pkg = pkg
+  )
+
   invisible(TRUE)
 }
 
-#' @export
-add_test_infrastructure <- use_testthat
-
 #' @section \code{use_test}:
 #' Add a test file, also add testing infrastructure if necessary.
 #' This will create \file{tests/testthat/test-<name>.R} with a user-specified
 #' name for the test.  Will fail if the file exists.
 #' @rdname infrastructure
-#' @aliases add_test_infrastructure
 #' @export
 use_test <- function(name, pkg = ".") {
   pkg <- as.package(pkg)
 
   check_suggested("testthat")
-  if (!uses_testthat(pkg)) {
-    use_testthat(pkg)
+  if (!uses_testthat(pkg = pkg)) {
+    use_testthat(pkg = pkg)
   }
 
-  path <- sprintf("tests/testthat/test-%s.R", name)
-  if (file.exists(file.path(pkg$path, path))) {
-    stop("File ", path, " exists", call. = FALSE)
-  }
-
-  writeLines(
-    render_template("test-example.R", list(test_name = name)),
-    file.path(pkg$path, path))
-
-  message("Test file created in ", path)
-}
-
-#' @section \code{use_rstudio}:
-#' Does not modify \code{.Rbuildignore} as RStudio will do that when
-#' opened for the first time.
-#' @export
-#' @rdname infrastructure
-#' @aliases add_rstudio_project
-use_rstudio <- function(pkg = ".") {
-  pkg <- as.package(pkg)
-
-  path <- file.path(pkg$path, paste0(pkg$package, ".Rproj"))
-  if (file.exists(path)) {
-    message("* RStudio infrastructure already initialized")
-    return(invisible(TRUE))
-  }
-
-  message("Adding RStudio project file to ", pkg$package)
-
-  template_path <- system.file("templates/template.Rproj", package = "devtools")
-  file.copy(template_path, path)
-
-  add_git_ignore(pkg, c(".Rproj.user", ".Rhistory", ".RData"))
-  add_build_ignore(pkg, c("^.*\\.Rproj$", "^\\.Rproj\\.user$"), escape = FALSE)
+  use_template("test-example.R",
+    sprintf("tests/testthat/test-%s.R", name),
+    data = list(test_name = name),
+    open = TRUE,
+    pkg = pkg
+  )
 
   invisible(TRUE)
 }
 
 #' @export
-add_rstudio_project <- use_rstudio
+#' @rdname infrastructure
+use_rstudio <- function(pkg = ".") {
+  pkg <- as.package(pkg)
 
+  use_template(
+    "template.Rproj",
+    paste0(pkg$package, ".Rproj"),
+    pkg = pkg
+  )
+
+  use_git_ignore(c(".Rproj.user", ".Rhistory", ".RData"), pkg = pkg)
+  use_build_ignore(c("^.*\\.Rproj$", "^\\.Rproj\\.user$"), escape = FALSE, pkg = pkg)
+
+  invisible(TRUE)
+}
 
 #' @section \code{use_vignette}:
 #' Adds needed packages to \code{DESCRIPTION}, and creates draft vignette
@@ -109,15 +92,15 @@ use_vignette <- function(name, pkg = ".") {
   add_desc_package(pkg, "Suggests", "knitr")
   add_desc_package(pkg, "Suggests", "rmarkdown")
   add_desc_package(pkg, "VignetteBuilder", "knitr")
-  dir.create(file.path(pkg$path, "vignettes"), showWarnings = FALSE)
 
-  add_git_ignore(pkg, "inst/doc")
+  use_directory("vignettes", pkg = pkg)
+  use_git_ignore("inst/doc", pkg = pkg)
 
   path <- file.path(pkg$path, "vignettes", paste0(name, ".Rmd"))
   rmarkdown::draft(path, "html_vignette", "rmarkdown",
     create_dir = FALSE, edit = FALSE)
 
-  message("Draft vignette created in ", path)
+  open_in_rstudio(path)
 }
 
 #' @section \code{use_rcpp}:
@@ -132,15 +115,18 @@ use_rcpp <- function(pkg = ".") {
   add_desc_package(pkg, "LinkingTo", "Rcpp")
   add_desc_package(pkg, "Imports", "Rcpp")
 
-  message("Creating src/ and src/.gitignore")
-  dir.create(file.path(pkg$path, "src"), showWarnings = FALSE)
-  union_write(file.path(pkg$path, "src", ".gitignore"),
-              c("*.o", "*.so", "*.dll"))
+  use_directory("src/", pkg = pkg)
+
+  message("* Ignoring generated binary files.")
+  ignore_path <- file.path(pkg$path, "src", ".gitignore")
+  union_write(ignore_path, c("*.o", "*.so", "*.dll"))
 
   message(
-    "Next, include the following roxygen tags somewhere in your package:\n",
+    "Next, include the following roxygen tags somewhere in your package:\n\n",
     "#' @useDynLib ", pkg$package, "\n",
-    "#' @importFrom Rcpp sourceCpp"
+    "#' @importFrom Rcpp sourceCpp\n",
+    "NULL\n\n",
+    "Then run document()"
   )
 }
 
@@ -153,37 +139,20 @@ use_rcpp <- function(pkg = ".") {
 use_travis <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  path <- file.path(pkg$path, ".travis.yml")
-  if (file.exists(path)) {
-    stop(".travis.yml already exists", call. = FALSE)
-  }
+  use_template("travis.yml", ".travis.yml", ignore = TRUE, pkg = pkg)
 
   gh <- github_info(pkg$path)
-  message("Adding .travis.yml to ", pkg$package, ". Next: \n",
+  message("Next: \n",
     " * Turn on travis for this repo at https://travis-ci.org/profile\n",
     " * Add a travis shield to your README.md:\n",
     "[![Travis-CI Build Status]",
-       "(https://travis-ci.org/", gh$username, "/", gh$repo, ".svg?branch=master)]",
-       "(https://travis-ci.org/", gh$username, "/", gh$repo, ")"
+       "(https://travis-ci.org/", gh$fullname, ".svg?branch=master)]",
+       "(https://travis-ci.org/", gh$fullname, ")"
   )
 
-  template_path <- system.file("templates/travis.yml", package = "devtools")
-  file.copy(template_path, path)
-
-  add_build_ignore(pkg, ".travis.yml")
-
   invisible(TRUE)
 }
 
-#' @rdname devtools-deprecated
-#' @section \code{use_coveralls}:
-#' Add coveralls to basic travis template to a package.
-#' @export
-use_coveralls <- function(pkg = ".") {
-  .Deprecated("use_coverage(type = \"coveralls\")", package = "devtools")
-  use_coverage(pkg, type = "coveralls")
-}
-
 #' @rdname infrastructure
 #' @param type CI tool to use. Currently supports codecov and coverall.
 #' @section \code{use_coverage}:
@@ -191,59 +160,49 @@ use_coveralls <- function(pkg = ".") {
 #' @export
 use_coverage <- function(pkg = ".", type = c("codecov", "coveralls")) {
   pkg <- as.package(pkg)
+  check_suggested("covr")
 
   path <- file.path(pkg$path, ".travis.yml")
   if (!file.exists(path)) {
-    stop(".travis.yml does not exist, please run `use_travis()` to create it", call. = FALSE)
+    use_travis()
   }
 
-  travis_content <- readLines(file.path(pkg$path, ".travis.yml"))
+  message("* Adding covr to Suggests")
+  add_desc_package(pkg, "Suggests", "covr")
 
+  gh <- github_info(pkg$path)
   type <- match.arg(type)
 
+  message("Next:")
   switch(type,
     codecov = {
-      if (any(grepl("codecov", travis_content))) {
-        stop("codecov information already added to .travis.yml", call. = FALSE)
-      }
-
-      gh <- github_info(pkg$path)
-      message("Adding codecov information into .travis.yml for ", pkg$package, ". Next: \n",
+      message("* Add to `README.md`: \n",
         "[![Coverage Status]",
-        "(https://img.shields.io/codecov/c/github/", gh$username, "/", gh$repo, "/master.svg)]",
-        "(https://codecov.io/github/", gh$username, "/", gh$repo, "?branch=master)\n",
-        " * Add the following to .travis.yml:\n",
-        "r_packages:\n",
-        "  - covr\n",
+        "(https://img.shields.io/codecov/c/github/", gh$fullname, "/master.svg)]",
+        "(https://codecov.io/github/", gh$fullname, "?branch=master)"
+      )
+      message("* Add to `.travis.yml`:\n",
         "after_success:\n",
-        "  - Rscript -e 'covr::codecov()'")
+        "  - Rscript -e 'covr::codecov()'"
+      )
     },
 
     coveralls = {
-      if (any(grepl("coveralls", travis_content))) {
-        stop("coveralls information already added to .travis.yml", call. = FALSE)
-      }
-
-      gh <- github_info(pkg$path)
-      message("Adding coveralls information into .travis.yml for ", pkg$package, ". Next: \n",
-        " * Turn on coveralls for this repo at https://coveralls.io/repos/new\n",
-        " * Add a coveralls shield to your README.md:\n",
+      message("* Turn on coveralls for this repo at https://coveralls.io/repos/new")
+      message("* Add to `README.md`: \n",
         "[![Coverage Status]",
-        "(https://img.shields.io/coveralls/", gh$username, "/", gh$repo, ".svg)]",
-        "(https://coveralls.io/r/", gh$username, "/", gh$repo, "?branch=master)\n",
-        " * Add the following to .travis.yml:\n",
-        "r_github_packages:\n",
-        "  - jimhester/covr\n",
+        "(https://img.shields.io/coveralls/", gh$fullname, ".svg)]",
+        "(https://coveralls.io/r/", gh$fullname, "?branch=master)"
+      )
+      message("* Add to `.travis.yml`:\n",
         "after_success:\n",
-        "  - Rscript -e 'covr::coveralls()'")
+        "  - Rscript -e 'covr::coveralls()'"
+      )
     })
 
   invisible(TRUE)
 }
 
-#' @export
-add_travis <- use_travis
-
 #' @rdname infrastructure
 #' @section \code{use_appveyor}:
 #' Add basic AppVeyor template to a package. Also adds \code{appveyor.yml} to
@@ -252,13 +211,10 @@ add_travis <- use_travis
 use_appveyor <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  path <- file.path(pkg$path, "appveyor.yml")
-  if (file.exists(path)) {
-    stop("appveyor.yml already exists", call. = FALSE)
-  }
+  use_template("appveyor.yml", ignore = TRUE, pkg = pkg)
 
   gh <- github_info(pkg$path)
-  message("Adding appveyor.yml to ", pkg$package, ". Next: \n",
+  message("Next: \n",
           " * Turn on AppVeyor for this repo at https://ci.appveyor.com/projects\n",
           " * Add an AppVeyor shield to your README.md:\n",
           "[![AppVeyor Build Status]",
@@ -266,11 +222,6 @@ use_appveyor <- function(pkg = ".") {
           "(https://ci.appveyor.com/project/", gh$username, "/", gh$repo, ")"
   )
 
-  template_path <- system.file("templates/appveyor.yml", package = "devtools")
-  file.copy(template_path, path)
-
-  add_build_ignore(pkg, "appveyor.yml")
-
   invisible(TRUE)
 }
 
@@ -281,14 +232,13 @@ use_appveyor <- function(pkg = ".") {
 use_package_doc <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  path <- file.path("R", paste(pkg$package, "-package.r", sep = ""))
-  if (file.exists(file.path(pkg$path, path))) {
-    stop(path, " already exists", call. = FALSE)
-  }
-
-  message("Creating ", path)
-  out <- render_template("packagename-package.r", list(name = pkg$package))
-  writeLines(out, file.path(pkg$path, path))
+  use_template(
+    "packagename-package.r",
+    file.path("R", paste(pkg$package, "-package.r", sep = "")),
+    data = list(name = pkg$package),
+    open = TRUE,
+    pkg = pkg
+  )
 }
 
 #' Use specified package.
@@ -323,7 +273,7 @@ use_package <- function(package, type = "Imports", pkg = ".") {
 
   type <- types[[match.arg(tolower(type), names(types))]]
 
-  message("Adding ", package, " to ", type)
+  message("* Adding ", package, " to ", type)
   add_desc_package(pkg, type, package)
 
   msg <- switch(type,
@@ -336,7 +286,9 @@ use_package <- function(package, type = "Imports", pkg = ".") {
     Enhances = "",
     LinkingTo = show_includes(package)
   )
+  message("Next: ")
   message(msg)
+  invisible()
 }
 
 show_includes <- function(package) {
@@ -474,14 +426,7 @@ check_data_paths <- function(paths, overwrite) {
 use_data_raw <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  path <- file.path(pkg$path, "data-raw")
-  if (file.exists(path)) {
-    stop("data-raw/ already exists", call. = FALSE)
-  }
-
-  message("Creating data-raw/")
-  dir.create(path)
-  add_build_ignore(pkg, "data-raw")
+  use_directory("data-raw", ignore = TRUE, pkg = pkg)
 
   message("Next: \n",
     "* Add data creation scripts in data-raw\n",
@@ -518,39 +463,24 @@ use_build_ignore <- function(files, escape = TRUE, pkg = ".") {
   invisible(TRUE)
 }
 
-#' Use README.Rmd
+#' Create README files.
 #'
-#' This creates `README.Rmd` from template and adds to \code{.Rbuildignore}.
+#' Use \code{Rmd} if you want a rich intermingling of code and data. Use
+#' \code{md} for a basic README. \code{README.Rmd} will be automatically
+#' added to \code{.Rbuildignore}.
 #'
-#' @param hook Hook name. One of "pre-commit", "prepare-commit-msg",
-#'   "commit-msg", "post-commit", "applypatch-msg", "pre-applypatch",
-#'   "post-applypatch", "pre-rebase", "post-rewrite", "post-checkout",
-#'   "post-merge", "pre-push", "pre-auto-gc".
-#' @param script Text of script to run
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
 #' @export
 #' @family infrastructure
-#' @keywords internal
 use_readme_rmd <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  readme_path <- file.path(pkg$path, "README.Rmd")
-  template <- render_template("README.Rmd")
-
-  if (!file.exists(readme_path)) {
-    message("Creating README.Rmd")
-    writeLines(template, readme_path)
-  } else {
-    rule("README.Rmd exists. Please check that it starts with:")
-    message(template)
-    rule()
-  }
-  use_build_ignore("README.Rmd", pkg = pkg)
+  use_template("README.Rmd", ignore = TRUE, open = TRUE, pkg = pkg)
   use_build_ignore("^README-.*\\.png$", escape = FALSE, pkg = pkg)
 
-  if (uses_git(pkg$path) && file.exists(pkg$path, ".git", "hooks", "pre-commit")) {
-    message("Adding pre-commit hook")
+  if (uses_git(pkg$path) && !file.exists(pkg$path, ".git", "hooks", "pre-commit")) {
+    message("* Adding pre-commit hook")
     use_git_hook("pre-commit", render_template("readme-rmd-pre-commit.sh"),
       pkg = pkg)
   }
@@ -558,6 +488,17 @@ use_readme_rmd <- function(pkg = ".") {
   invisible(TRUE)
 }
 
+#' @export
+#' @rdname use_readme_rmd
+use_readme_md <- function(pkg = ".") {
+  pkg <- as.package(pkg)
+  if (uses_github(pkg$path)) {
+    pkg$github <- github_info(pkg$path)
+  }
+
+  use_template("README.md", data = pkg, open = TRUE, pkg = pkg)
+}
+
 #' Use NEWS.md
 #'
 #' This creates \code{NEWS.md} from a template.
@@ -569,17 +510,7 @@ use_readme_rmd <- function(pkg = ".") {
 use_news_md <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  news_path <- file.path(pkg$path, "NEWS.md")
-  template <- render_template("NEWS.md", pkg)
-
-  if (!file.exists(news_path)) {
-    message("Creating NEWS.md")
-    writeLines(template, news_path)
-  } else {
-    stop("NEWS.md already exists", call. = FALSE)
-  }
-
-  invisible(TRUE)
+  use_template("NEWS.md", data = pkg, open = TRUE, pkg = pkg)
 }
 
 #' @rdname infrastructure
@@ -590,19 +521,13 @@ use_news_md <- function(pkg = ".") {
 use_revdep <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  message("Creating revdep/ & adding to .Rbuildignore")
-  dir.create(file.path(pkg$path, "revdep"), showWarnings = FALSE)
-  use_build_ignore("revdep", pkg = pkg)
-
-  message("Add revdep subdirectories to .gitignore")
-  path <- file.path(pkg$path, "revdep", ".gitignore")
-  union_write(path, "**/")
-
-  if (!file.exists(file.path(pkg$path, "revdep/check.R"))) {
-    message("Adding revdep/check.R template")
-    writeLines(render_template("revdep.R", list(name = pkg$package)),
-      file.path(pkg$path, "revdep", "check.R"))
-  }
+  use_directory("revdep", ignore = TRUE, pkg = pkg)
+  use_template(
+    "revdep.R",
+    "revdep/check.R",
+    data = list(name = pkg$package),
+    pkg = pkg
+  )
 }
 
 #' @rdname infrastructure
@@ -613,18 +538,14 @@ use_revdep <- function(pkg = ".") {
 use_cran_comments <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  use_build_ignore("cran-comments.md")
-
-  comments <- file.path(pkg$path, "cran-comments.md")
-  if (file.exists(comments))
-    stop("cran-comments.md already exists", call. = FALSE)
-
-  message("Adding cran-comments.md template")
-  data <- list(
-    rversion = paste0(version$major, ".", version$minor)
+  use_template(
+    "cran-comments.md",
+    data = list(rversion = paste0(version$major, ".", version$minor)),
+    ignore = TRUE,
+    open = TRUE,
+    pkg = pkg
   )
 
-  writeLines(render_template("cran-comments.md", data), comments)
   invisible()
 }
 
@@ -637,15 +558,11 @@ use_cran_comments <- function(pkg = ".") {
 use_code_of_conduct <- function(pkg = ".") {
   pkg <- as.package(pkg)
 
-  comments <- file.path(pkg$path, "CONDUCT.md")
-  if (file.exists(comments))
-    stop("CONDUCT.md already exists", call. = FALSE)
-
-  message("* Creating CONDUCT.md")
-  writeLines(render_template("CONDUCT.md", list()), comments)
-
-  message("* Adding CONDUCT.md to .Rbuildignore")
-  use_build_ignore("CONDUCT.md")
+  use_template(
+    "CONDUCT.md",
+    ignore = TRUE,
+    pkg = pkg
+  )
 
   message("* Don't forget to describe the code of conduct in your README.md:")
   message("Please note that this project is released with a ",
@@ -677,7 +594,7 @@ use_cran_badge <- function(pkg = ".") {
   pkg <- as.package(pkg)
   message(
     " * Add a CRAN status shield by adding the following line to your README:\n",
-    "[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/", pkg$package, ")](http://cran.r-project.org/package=", pkg$package, ")"
+    "[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/", pkg$package, ")](https://cran.r-project.org/package=", pkg$package, ")"
   )
   invisible(TRUE)
 }
@@ -693,24 +610,95 @@ use_mit_license <- function(pkg = ".", copyright_holder = getOption("devtools.na
   pkg <- as.package(pkg)
 
   # Update the DESCRIPTION
+  message("* Updating license field in DESCRIPTION.")
   descPath <- file.path(pkg$path, "DESCRIPTION")
   DESCRIPTION <- read_dcf(descPath)
   DESCRIPTION$License <- "MIT + file LICENSE"
   write_dcf(descPath, DESCRIPTION)
 
-  # Update the license
-  licensePath <- file.path(pkg$path, "LICENSE")
-  if (file.exists(licensePath))
-    if (!file.remove(licensePath))
-      stop("Failed to remove license file '", licensePath, "'", call. = FALSE)
-
-  # Write the MIT template
-  template <- c(
-    paste("YEAR:", format(Sys.Date(), "%Y")),
-    paste("COPYRIGHT HOLDER:", copyright_holder)
+  use_template(
+    "mit-license.txt",
+    "LICENSE",
+    data = list(
+      year = format(Sys.Date(), "%Y"),
+      copyright_holder = copyright_holder
+    ),
+    open = identical(copyright_holder, "<Author>"),
+    pkg = pkg
   )
-
-  writeLines(template, con = licensePath)
-  message("* Added infrastructure for MIT license")
-  licensePath
 }
+
+use_directory <- function(path, ignore = FALSE, pkg = ".") {
+  pkg <- as.package(pkg)
+  pkg_path <- file.path(pkg$path, path)
+
+  if (file.exists(pkg_path)) {
+    if (!is_dir(pkg_path)) {
+      stop("`", path, "` exists but is not a directory.", call. = FALSE)
+    }
+  } else {
+    message("* Creating `", path, "`.")
+    dir.create(pkg_path, showWarnings = FALSE, recursive = TRUE)
+  }
+
+  if (ignore) {
+    message("* Adding `", path, "` to `.Rbuildignore`.")
+    use_build_ignore(path, pkg = pkg)
+  }
+
+  invisible(TRUE)
+}
+
+use_template <- function(template, save_as = template, data = list(),
+                         ignore = FALSE, open = FALSE, pkg = ".") {
+  pkg <- as.package(pkg)
+
+  path <- file.path(pkg$path, save_as)
+  if (!can_overwrite(path)) {
+    stop("`", save_as, "` already exists.", call. = FALSE)
+  }
+
+  template_path <- system.file("templates", template, package = "devtools",
+    mustWork = TRUE)
+  template_out <- whisker::whisker.render(readLines(template_path), data)
+
+  message("* Creating `", save_as, "` from template.")
+  writeLines(template_out, path)
+
+  if (ignore) {
+    message("* Adding `", save_as, "` to `.Rbuildignore`.")
+    use_build_ignore(save_as, pkg = pkg)
+  }
+
+  if (open) {
+    message("* Modify `", save_as, "`.")
+    open_in_rstudio(save_as)
+  }
+
+  invisible(TRUE)
+}
+
+open_in_rstudio <- function(path) {
+  if (!rstudioapi::isAvailable())
+    return()
+
+  if (!rstudioapi::hasFun("navigateToFile"))
+    return()
+
+  rstudioapi::navigateToFile(path)
+
+}
+
+can_overwrite <- function(path) {
+  name <- basename(path)
+
+  if (!file.exists(path)) {
+    TRUE
+  } else if (interactive() && !yesno("Overwrite `", name, "`?")) {
+    TRUE
+  } else {
+    FALSE
+  }
+}
+
+
