@@ -39,10 +39,21 @@ remote_download.local_remote <- function(x, quiet = FALSE) {
 
 #' @export
 remote_metadata.local_remote <- function(x, bundle = NULL, source = NULL) {
-  list(
+  res <- list(
     RemoteType = "local",
-    RemoteUrl = x$path,
-    RemoteSubdir = x$subdir,
-    RemoteSha = if (uses_git(x$path)) git_sha1(path = x$path)
+    RemoteUrl = x$path
   )
+
+  if (uses_git(x$path) && !git_uncommitted(x$path)) {
+    res$RemoteSha <- git_sha1(path = x$path)
+  }
+  if (uses_github(x$path)) {
+    info <- github_info(x$path)
+    res$RemoteUsername <- info$username
+    res$RemoteRepo <- info$repo
+  }
+  res
 }
+
+#' @export
+remote_metadata.package <- remote_metadata.local_remote
